@@ -7,6 +7,7 @@
 #include "config-kitinerary.h"
 #include "calendarhandler.h"
 #include "jsonlddocument.h"
+#include "locationutil_p.h"
 #include "logging.h"
 #include "mergeutil.h"
 #include "sortutil.h"
@@ -23,13 +24,10 @@
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
-#ifdef HAVE_KCAL
 #include <KCalendarCore/Alarm>
 #include <KCalendarCore/Calendar>
 #include <KCalendarCore/Event>
-#endif
 
-#include <kcontacts_version.h>
 #include <KContacts/Address>
 
 #include <KLocalizedString>
@@ -40,36 +38,16 @@
 
 using namespace KItinerary;
 
-static KContacts::Address convertAddress(const PostalAddress &addr)
-{
-    KContacts::Address a;
-    a.setStreet(addr.streetAddress());
-    a.setPostalCode(addr.postalCode());
-    a.setLocality(addr.addressLocality());
-    a.setRegion(addr.addressRegion());
-    a.setCountry(addr.addressCountry());
-    return a;
-}
-
 static QString formatAddress(const PostalAddress &addr)
 {
-#if KContacts_VERSION >= QT_VERSION_CHECK(5, 92, 0)
-    return convertAddress(addr).formatted(KContacts::AddressFormatStyle::MultiLineInternational);
-#else
-    return convertAddress(addr).formattedAddress();
-#endif
+    return LocationUtil::toAddress(addr).formatted(KContacts::AddressFormatStyle::MultiLineInternational);
 }
 
 static QString formatAddressSingleLine(const PostalAddress &addr)
 {
-#if KContacts_VERSION >= QT_VERSION_CHECK(5, 92, 0)
-    return convertAddress(addr).formatted(KContacts::AddressFormatStyle::SingleLineInternational);
-#else
-    return formatAddress(addr).replace(QLatin1String("\n\n"), QLatin1String("\n")).replace(QLatin1Char('\n'), QLatin1String(", "));
-#endif
+    return LocationUtil::toAddress(addr).formatted(KContacts::AddressFormatStyle::SingleLineInternational);
 }
 
-#ifdef HAVE_KCAL
 using namespace KCalendarCore;
 static void fillFlightReservation(const QVector<QVariant> &reservations, const KCalendarCore::Event::Ptr &event);
 static void fillTrainReservation(const TrainReservation &reservation, const KCalendarCore::Event::Ptr &event);
@@ -81,11 +59,14 @@ static void fillGeoPosition(const QVariant &place, const KCalendarCore::Event::P
 static void fillFoodReservation(const FoodEstablishmentReservation &reservation, const KCalendarCore::Event::Ptr &event);
 static void fillRentalCarReservation(const RentalCarReservation &reservation, const KCalendarCore::Event::Ptr &event);
 static void fillTaxiReservation(const TaxiReservation &reservation, const KCalendarCore::Event::Ptr &event);
-#endif
 
-QVector<QSharedPointer<KCalendarCore::Event> > CalendarHandler::findEvents(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
+QVector<QSharedPointer<KCalendarCore::Event>> CalendarHandler::findEvents(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
+{
+    return findEvents(calendar.data(), reservation);
+}
+
+QVector<QSharedPointer<KCalendarCore::Event>> CalendarHandler::findEvents(KCalendarCore::Calendar *calendar, const QVariant &reservation)
 {
-#ifdef HAVE_KCAL
     if (!(JsonLd::canConvert<Reservation>(reservation) || JsonLd::canConvert<KItinerary::Event>(reservation)) || !calendar) {
         return {};
     }
@@ -119,40 +100,17 @@ QVector<QSharedPointer<KCalendarCore::Event> > CalendarHandler::findEvents(const
     }
 
     return results;
-#else
-    Q_UNUSED(calendar)
-    Q_UNUSED(reservation)
-    return {};
-#endif
-}
-
-QSharedPointer<KCalendarCore::Event> CalendarHandler::findEvent(const QSharedPointer<KCalendarCore::Calendar> &calendar, const QVariant &reservation)
-{
-#ifdef HAVE_KCAL
-    const auto evs = findEvents(calendar, reservation);
-    return evs.empty() ? KCalendarCore::Event::Ptr() : evs.at(0);
-#else
-    Q_UNUSED(calendar)
-    Q_UNUSED(reservation)
-    return {};
-#endif
 }
 
 QVector<QVariant> CalendarHandler::reservationsForEvent(const QSharedPointer<KCalendarCore::Event> &event)
 {
-#ifdef HAVE_KCAL
     const auto payload = event->customProperty("KITINERARY", "RESERVATION").toUtf8();
     const auto json = QJsonDocument::fromJson(payload).array();
     return JsonLdDocument::fromJson(json);
-#else
-    Q_UNUSED(event)
-    return {};
-#endif
 }
 
 bool CalendarHandler::canCreateEvent(const QVariant &reservation)
 {
-#ifdef HAVE_KCAL
     if (JsonLd::isA<FlightReservation>(reservation)) {
         const auto f = reservation.value<FlightReservation>().reservationFor().value<Flight>();
         if (f.departureTime().isValid() && f.arrivalTime().isValid()) {
@@ -160,10 +118,6 @@ bool CalendarHandler::canCreateEvent(const QVariant &reservation)
         }
     }
     return SortUtil::startDateTime(reservation).isValid();
-#else
-    Q_UNUSED(reservation)
-    return false;
-#endif
 }
 
 void CalendarHandler::fillEvent(const QVector<QVariant> &reservations, const QSharedPointer<KCalendarCore::Event> &event)
@@ -172,7 +126,6 @@ void CalendarHandler::fillEvent(const QVector<QVariant> &reservations, const QSh
         return;
     }
 
-#ifdef HAVE_KCAL
     // TODO pass reservationS into all functions below for multi-traveler support
     const auto &reservation = reservations.at(0);
     const int typeId = reservation.userType();
@@ -210,12 +163,8 @@ void CalendarHandler::fillEvent(const QVector<QVariant> &reservations, const QSh
 
     const auto payload = QJsonDocument(JsonLdDocument::toJson(reservations)).toJson(QJsonDocument::Compact);
     event->setCustomProperty("KITINERARY", "RESERVATION", QString::fromUtf8(payload));
-#else
-    Q_UNUSED(event)
-#endif
 }
 
-#ifdef HAVE_KCAL
 static QString airportDisplayCode(const Airport &airport)
 {
     return airport.iataCode().isEmpty() ? airport.name() : airport.iataCode();
@@ -545,4 +494,3 @@ static void fillTaxiReservation(const TaxiReservation &reservation, const KCalen
     event->setDescription(description);
 }
 
-#endif
