@@ -9,16 +9,17 @@
 #include "extractorpostprocessor_p.h"
 #include "extractorvalidator.h"
 #include "flightpostprocessor_p.h"
+#include "stringutil.h"
 
-#include "extractorutil.h"
 #include "iata/iatabcbpparser.h"
 #include "jsonlddocument.h"
 #include "logging.h"
 #include "mergeutil.h"
 #include "sortutil.h"
+#include "text/addressparser_p.h"
 
 #include "knowledgedb/airportdb.h"
-#include "knowledgedb/timezonedb.h"
+#include "knowledgedb/timezonedb_p.h"
 #include "knowledgedb/trainstationdb.h"
 
 #include <KItinerary/Action>
@@ -44,7 +45,7 @@
 #include <QTimeZone>
 #include <QUrl>
 
-#ifdef HAVE_PHONENUMBER
+#if HAVE_PHONENUMBER
 #include <phonenumbers/phonenumberutil.h>
 #endif
 
@@ -117,16 +118,53 @@ void ExtractorPostprocessor::process(const QVector<QVariant> &data)
             elem = d->processEvent(elem.value<Event>());
         }
 
+        // non-reservation types
+        else if (JsonLd::isA<ProgramMembership>(elem)) {
+            elem = d->processProgramMembership(elem.value<ProgramMembership>());
+        } else if (JsonLd::isA<Ticket>(elem)) {
+            elem = d->processTicket(elem.value<Ticket>());
+        }
+
         d->mergeOrAppend(elem);
     }
 }
 
 QVector<QVariant> ExtractorPostprocessor::result() const
 {
-    if (!d->m_resultFinalized && d->m_validationEnabled) {
-        d->m_data.erase(std::remove_if(d->m_data.begin(), d->m_data.end(), [this](const auto &elem) {
-            return !d->m_validator.isValidElement(elem);
-        }), d->m_data.end());
+    if (!d->m_resultFinalized) {
+        if (d->m_validationEnabled) {
+            d->m_data.erase(std::remove_if(d->m_data.begin(), d->m_data.end(), [this](const auto &elem) {
+                return !d->m_validator.isValidElement(elem);
+            }), d->m_data.end());
+        }
+
+        // search for "triangular" patterns, ie. a location change element that has a matching departure
+        // and matching arrival to two different other location change elements (A->C vs A->B + B->C).
+        // we remove those, as the fine-granular results are better
+        if (d->m_data.size() >= 3) {
+            for (auto it = d->m_data.begin(); it != d->m_data.end();) {
+                auto depIt = it;
+                auto arrIt = it;
+                for (auto it2 = d->m_data.begin(); it2 != d->m_data.end(); ++it2) {
+                    if (it == it2) {
+                        continue;
+                    }
+                    if (MergeUtil::hasSameDeparture(*it, *it2)) {
+                        depIt = it2;
+                    }
+                    if (MergeUtil::hasSameArrival(*it, *it2)) {
+                        arrIt = it2;
+                    }
+                }
+
+                if (depIt != it && arrIt != it && depIt != arrIt) {
+                    it = d->m_data.erase(it);
+                } else {
+                    ++it;
+                }
+            }
+        }
+
         d->m_resultFinalized = true;
     }
 
@@ -268,6 +306,12 @@ TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation sta
     } else if (id.startsWith(QLatin1String("amtrak:")) && id.size() == 10) {
         const auto record = KnowledgeDb::stationForAmtrakStationCode(KnowledgeDb::AmtrakStationCode(QStringView(id).mid(7)));
         applyStationData(record, station);
+    } else if (id.startsWith(QLatin1String("via:")) && id.size() == 8) {
+        const auto record = KnowledgeDb::stationForViaRailStationCode(KnowledgeDb::ViaRailStationCode(QStringView(id).mid(4)));
+        applyStationData(record, station);
+    } else if (id.startsWith(QLatin1String("uk:")) && id.size() == 6) {
+        const auto record = KnowledgeDb::stationForUkRailwayStationCode(KnowledgeDb::UKRailwayStationCode(QStringView(id).mid(3)));
+        applyStationData(record, station);
     }
 
     return processPlace(station);
@@ -282,28 +326,7 @@ QDateTime ExtractorPostprocessorPrivate::processTrainTripTime(QDateTime dt, QDat
     if (dt.date().year() <= 1970 && departureDay.isValid()) { // we just have the time, but not the day
         dt.setDate(departureDay);
     }
-
-    if (dt.timeSpec() == Qt::TimeZone) {
-        return dt;
-    }
-
-    const auto tz = KnowledgeDb::timezoneForLocation(station.geo().latitude(), station.geo().longitude(), station.address().addressCountry(), station.address().addressRegion());
-    if (!tz.isValid()) {
-        return dt;
-    }
-
-    // prefer our timezone over externally provided UTC offset, if they match
-    if (dt.timeSpec() == Qt::OffsetFromUTC && tz.offsetFromUtc(dt) != dt.offsetFromUtc()) {
-        return dt;
-    }
-
-    if (dt.timeSpec() == Qt::OffsetFromUTC || dt.timeSpec() == Qt::LocalTime) {
-        dt.setTimeSpec(Qt::TimeZone);
-        dt.setTimeZone(tz);
-    } else if (dt.timeSpec() == Qt::UTC) {
-        dt = dt.toTimeZone(tz);
-    }
-    return dt;
+    return processTimeForLocation(dt, station);
 }
 
 BusReservation ExtractorPostprocessorPrivate::processBusReservation(BusReservation res) const
@@ -388,7 +411,7 @@ EventReservation ExtractorPostprocessorPrivate::processEventReservation(EventRes
 
 KItinerary::Event ExtractorPostprocessorPrivate::processEvent(KItinerary::Event event) const
 {
-    event.setName(event.name().trimmed());
+    event.setName(StringUtil::clean(event.name()));
 
     // normalize location to be a Place
     if (JsonLd::isA<PostalAddress>(event.location())) {
@@ -409,6 +432,14 @@ KItinerary::Event ExtractorPostprocessorPrivate::processEvent(KItinerary::Event
     return event;
 }
 
+Ticket ExtractorPostprocessorPrivate::processTicket(Ticket ticket) const
+{
+    ticket.setName(StringUtil::clean(ticket.name()));
+    ticket.setTicketNumber(ticket.ticketNumber().simplified());
+    ticket.setUnderName(processPerson(ticket.underName()));
+    return ticket;
+}
+
 ProgramMembership ExtractorPostprocessorPrivate::processProgramMembership(ProgramMembership program) const
 {
     program.setProgramName(program.programName().simplified());
@@ -427,6 +458,10 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
     res.setPotentialAction(processActions(res.potentialAction()));
     res.setReservationNumber(res.reservationNumber().trimmed());
     res.setProgramMembershipUsed(processProgramMembership(res.programMembershipUsed()));
+
+    if (JsonLd::isA<Ticket>(res.reservedTicket())) {
+        res.setReservedTicket(processTicket(res.reservedTicket().template value<Ticket>()));
+    }
     return res;
 }
 
@@ -484,7 +519,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
     addr.setAddressLocality(addr.addressLocality().simplified());
     addr.setAddressRegion(addr.addressRegion().simplified());
 
-#ifdef HAVE_PHONENUMBER
+#if HAVE_PHONENUMBER
     // recover country from phone number, if we have that
     if (!phoneNumber.isEmpty() && addr.addressCountry().size() != 2) {
         const auto phoneStr = phoneNumber.toStdString();
@@ -504,13 +539,16 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
         addr.setAddressCountry(KCountry::fromLocation(geo.latitude(), geo.longitude()).alpha2());
     }
 
-    addr = ExtractorUtil::extractPostalCode(addr);
+    AddressParser addrParser;
+    addrParser.setFallbackCountry(KCountry::fromQLocale(QLocale().country()).alpha2());
+    addrParser.parse(addr);
+    addr = addrParser.result();
     return addr;
 }
 
 QString ExtractorPostprocessorPrivate::processPhoneNumber(const QString &phoneNumber, const PostalAddress &addr)
 {
-#ifdef HAVE_PHONENUMBER
+#if HAVE_PHONENUMBER
     // or complete the phone number if we know the country
     if (!phoneNumber.isEmpty() && addr.addressCountry().size() == 2) {
         auto phoneStr = phoneNumber.toStdString();
@@ -578,7 +616,7 @@ QVariantList ExtractorPostprocessorPrivate::processActions(QVariantList actions)
 template <typename T>
 QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, const T &place) const
 {
-    if (!dt.isValid() || dt.timeSpec() == Qt::TimeZone) {
+    if (!dt.isValid() || (dt.timeSpec() == Qt::TimeZone && dt.timeZone() != QTimeZone::utc())) {
         return dt;
     }
 
@@ -596,7 +634,7 @@ QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, co
     if (dt.timeSpec() == Qt::OffsetFromUTC || dt.timeSpec() == Qt::LocalTime) {
         dt.setTimeSpec(Qt::TimeZone);
         dt.setTimeZone(tz);
-    } else if (dt.timeSpec() == Qt::UTC) {
+    } else if (dt.timeSpec() == Qt::UTC || (dt.timeSpec() == Qt::TimeZone && dt.timeZone() == QTimeZone::utc())) {
         dt = dt.toTimeZone(tz);
     }
     return dt;
