@@ -324,5 +324,39 @@ function parseEvent(event) {
     res.reservationFor.departureTime = JsonLd.readQDateTime(event, 'dtStart');
     res.reservationFor.arrivalStation.name = names[2];
     res.reservationFor.arrivalTime = JsonLd.readQDateTime(event, 'dtEnd');
+
+    // search for more details in the description
+    let reservations = [];
+    let idx = 0;
+    while (true) {
+        const trip = event.description.substr(idx).match(/(\d{2}:\d{2}) (.*?)(?:- (?:Gleis|platform|voie|Vía|Spor|Kolej|binario|Peron) (.*?))?(?: \((.*\d+)\))?\n.* (\d{2}:\d{2}) (.*?)(?:\n| - (?:Gleis|platform|voie|Vía|Spor|Kolej|binario|Peron) (.*)\n)/);
+        if (!trip) {
+            break;
+        }
+        idx += trip.index + trip[0].length;
+
+        let res = JsonLd.newTrainReservation();
+        const date = JsonLd.readQDateTime(event, 'dtStart')['@value'].substr(0, 10);
+        res.reservationFor.departureStation.name = trip[2];
+        res.reservationFor.departureTime = JsonLd.toDateTime(date + trip[1], 'yyyy-MM-ddhh:mm', 'de');
+        res.reservationFor.departurePlatform = trip[3];
+        res.reservationFor.trainName = trip[4];
+        res.reservationFor.arrivalStation.name = trip[6];
+        res.reservationFor.arrivalTime = JsonLd.toDateTime(date + trip[5], 'yyyy-MM-ddhh:mm', 'de');
+        res.reservationFor.arrivalPlatform = trip[7];
+
+        if (trip[4] && trip[4].match(/^Bus[ \d]/)) {
+            res = JsonLd.trainToBusReservation(res);
+        }
+
+        reservations.push(res);
+    }
+    // recover full timezones for the begin/end
+    if (reservations.length > 0) {
+        reservations[0].reservationFor.departureTime = res.reservationFor.departureTime;
+        reservations[reservations.length - 1].reservationFor.arrivalTime = res.reservationFor.arrivalTime;
+        return reservations;
+    }
+
     return res;
 }
