@@ -23,11 +23,11 @@ const tariffs = {
 
 function parseSncfPdfText(text) {
     var reservations = new Array();
-    var bookingRef = text.match(/(?:DOSSIER VOYAGE|BOOKING FILE REFERENCE|REFERENCE NUMBER) ?: +([A-Z0-9]{6})/);
+    var bookingRef = text.match(/(?:DOSSIER VOYAGE|BOOKING FILE REFERENCE|REFERENCE NUMBER|REISEREFERENZ) ?: +([A-Z0-9]{6})/);
 
     var pos = 0;
     while (true) {
-        var header = text.substr(pos).match(/ +(?:Départ \/ Arrivée|Departure \/ Arrival).*\n/);
+        var header = text.substr(pos).match(/ +(?:Départ \/ Arrivée|Departure \/ Arrival|Abfahrt \/ Ankunft).*\n/);
         if (!header)
             break;
         var index = header.index + header[0].length;
@@ -35,28 +35,28 @@ function parseSncfPdfText(text) {
         var res = JsonLd.newTrainReservation();
         res.reservationNumber = bookingRef[1];
 
-        var depLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) (?:à|at) (\d{2}[h:]\d{2})/);
+        var depLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}[\/\.]\d{2}) (?:à|at|um) (\d{2}[h:]\d{2})/);
         if (!depLine)
             break;
         index += depLine.index + depLine[0].length;
         res.reservationFor.departureStation.name = depLine[1];
-        res.reservationFor.departureTime = JsonLd.toDateTime(depLine[2] + " " + depLine[3], ["dd/MM hh'h'mm", "dd/MM hh:mm"], "fr");
+        res.reservationFor.departureTime = JsonLd.toDateTime(depLine[2] + " " + depLine[3], ["dd/MM hh'h'mm", "dd/MM hh:mm", "dd.MM hh:mm"], "fr");
 
-        var arrLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}\/\d{2}) (?:à|at) (\d{2}[h:]\d{2})/);
+        var arrLine = text.substr(pos + index).match(/\n {2,3}([\w -]+?)  +(\d{2}[\/\.]\d{2}) (?:à|at|um) (\d{2}[h:]\d{2})/);
         if (!arrLine)
             break;
         index += arrLine.index + arrLine[0].length;
         res.reservationFor.arrivalStation.name = arrLine[1];
-        res.reservationFor.arrivalTime = JsonLd.toDateTime(arrLine[2] + " " + arrLine[3], ["dd/MM hh'h'mm", "dd/MM hh:mm"], "fr");
+        res.reservationFor.arrivalTime = JsonLd.toDateTime(arrLine[2] + " " + arrLine[3], ["dd/MM hh'h'mm", "dd/MM hh:mm", "dd.MM hh:mm"], "fr");
 
         // parse seat, train number, etc from the text for one leg
         // since the stations are vertically centered, the stuff we are looking for might be at different
         // positions relative to them
         var legText = text.substring(pos + header.index + header[0].length, pos + index);
-        var trainNumber = legText.match(/TRAIN (?:N°|NUMBER) ?(\d{3,5})/);
+        var trainNumber = legText.match(/(?:TRAIN N°|TRAIN NUMBER|ZUGNUMMER) ?(\d{3,5})/);
         if (trainNumber)
             res.reservationFor.trainNumber = trainNumber[1];
-        var seatRes = legText.match(/(?:VOITURE|COACH) (\d+) - (?:PLACE|SEAT) (\d+)/);
+        var seatRes = legText.match(/(?:VOITURE|COACH|WAGEN) (\d+) - (?:PLACE|SEAT|PLATZ) (\d+)/);
         if (seatRes) {
             res.reservedTicket.ticketedSeat.seatSection = seatRes[1];
             res.reservedTicket.ticketedSeat.seatNumber = seatRes[2];
@@ -76,7 +76,7 @@ function parseInouiPdfText(page)
     var reservations = new Array();
     var text = page.textInRect(0.0, 0.0, 0.5, 1.0);
 
-    var date = text.match(/(\d+ [^ ]+ \d{4})\n/)
+    var date = text.match(/(\d+\.? [^ ]+ \d{4})\n/)
     if (!date)
         return reservations;
     var pos = date.index + date[0].length;
@@ -87,20 +87,20 @@ function parseInouiPdfText(page)
         pos += dep.index + dep[0].length;
 
         var res = JsonLd.newTrainReservation();
-        res.reservationFor.departureTime = JsonLd.toDateTime(date[1] + dep[1], ["d MMMM yyyyhh'h'mm", "dd MMMM yyyyhh:mm"], ["fr", "en"]);
+        res.reservationFor.departureTime = JsonLd.toDateTime(date[1] + dep[1], ["d MMMM yyyyhh'h'mm", "dd MMMM yyyyhh:mm", "dd. MMMM yyyyhh:mm"], ["fr", "en", "de"]);
         res.reservationFor.departureStation.name = dep[2];
 
         var arr = text.substr(pos).match(/(\d{2}[h:]\d{2}) +(.*)\n/);
         if (!arr)
             break;
         var endPos = arr.index + arr[0].length;
-        res.reservationFor.arrivalTime = JsonLd.toDateTime(date[1] + arr[1], ["d MMMM yyyyhh'h'mm", "dd MMMM yyyyhh:mm"], ["fr", "en"]);
+        res.reservationFor.arrivalTime = JsonLd.toDateTime(date[1] + arr[1], ["d MMMM yyyyhh'h'mm", "dd MMMM yyyyhh:mm", "dd. MMMM yyyyhh:mm"], ["fr", "en", "de"]);
         res.reservationFor.arrivalStation.name = arr[2];
 
         var detailsText = text.substr(pos, endPos - arr[0].length);
         var train = detailsText.match(/^ *(.*?) *-/);
         res.reservationFor.trainNumber = train[1];
-        var seat = detailsText.match(/(?:Voiture|Coach) *(\d+) *(?:Place|Seat) *(\d+)/);
+        var seat = detailsText.match(/(?:Voiture|Coach|Wagen) *(\d+) *(?:Place|Seat|Platz) *(\d+)/);
         if (seat) {
             res.reservedTicket.ticketedSeat.seatSection = seat[1];
             res.reservedTicket.ticketedSeat.seatNumber = seat[2];
@@ -230,7 +230,7 @@ function parseSecutixPdfItineraryV2(text, res)
     var reservations = new Array();
     var pos = 0;
     while (true) {
-        var data = text.substr(pos).match(/(\d+h\d+)\n(.*)\n(.*)\n(\d+h\d+)\n(.*)\n/);
+        var data = text.substr(pos).match(/ *(\d+h\d+)\n *(.*)\n *(.*)\n(?: *Voiture (\d+) - Place (\d+)\n.*\n.*\n)? *(\d+h\d+)\n(.*)\n/);
         if (!data)
             break;
         pos += data.index + data[0].length;
@@ -239,12 +239,14 @@ function parseSecutixPdfItineraryV2(text, res)
         leg.reservationFor.departureStation.name = data[2];
         leg.reservationFor.departureDay = res.reservationFor.departureDay;
         leg.reservationFor.departureTime = JsonLd.toDateTime(data[1], "hh'h'mm", "fr");
-        leg.reservationFor.arrivalStation.name = data[5];
-        leg.reservationFor.arrivalTime = JsonLd.toDateTime(data[4], "hh'h'mm", "fr");
+        leg.reservationFor.arrivalStation.name = data[7];
+        leg.reservationFor.arrivalTime = JsonLd.toDateTime(data[6], "hh'h'mm", "fr");
         leg.reservationFor.trainNumber = data[3];
         leg.underName = res.underName;
         leg.reservationNumber = res.reservationNumber;
         leg.reservedTicket = res.reservedTicket;
+        leg.reservedTicket.ticketedSeat.seatSection = data[4];
+        leg.reservedTicket.ticketedSeat.seatNumber = data[5];
         leg.programMembershipUsed = res.programMembershipUsed;
 
         reservations.push(leg);
@@ -513,3 +515,24 @@ function parseSncfCartePdf(pdf, node, barcode) {
     carte.validTo = JsonLd.toDateTime(validity[2] + ' 23:59:59', 'dd/MM/yyyy hh:mm:ss', 'fr');
     return carte;
 }
+
+// see https://community.kde.org/KDE_PIM/KItinerary/SNCF_Barcodes#SNCF_Normandie_Tickets
+// PDF layout matches that of the "secutix" v2
+function parseSncfNormandie(pdf, node, triggerNode) {
+    let res = JsonLd.newTrainReservation();
+    res.reservedTicket.ticketToken = "aztecbin:" + ByteArray.toBase64(triggerNode.content);
+
+    const page = pdf.pages[triggerNode.location];
+    const textRight = page.textInRect(0.5, 0.0, 1.0, 1.0);
+    const pnr = textRight.match(/(.*)\n(.*)\n\d{2}\/\d{2}\/\d{4} +(?:PAO|REF)\s*:\s*([A-Z0-9]{6,8})\n/);
+    res.reservationNumber = pnr[3];
+    res.underName.givenName = pnr[2];
+    res.underName.familyName = pnr[1];
+    res.reservedTicket.ticketedSeat.seatingType = textRight.match(/Classe (.*)\n/)[1];
+
+    const textLeft = pdf.pages[triggerNode.location].textInRect(0.0, 0.0, 0.5, 1.0);
+    const date = textLeft.match(/(\d{1,2} \S+ \d{4})/)[1];
+    res.reservationFor.departureDay = JsonLd.toDateTime(date, 'd MMMM yyyy', 'fr');
+    let reservations = parseSecutixPdfItineraryV2(textLeft, res);
+    return reservations;
+}
